@@ -11,6 +11,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+if [ -n "$DLRNAPI_DBPATH" ];
+then
+    export CONFIG_FILE='/data/custom_config.py'
+    echo "DB_PATH = \"$DLRNAPI_DBPATH\"" > /data/custom_config.py
+fi
+
 if [ -n "$DLRNAPI_USE_SAMPLE_DATA" ];
 then
     python3 /import.py
