@@ -16,6 +16,7 @@ from dlrn.drivers.pkginfo import PkgInfoDriver
 from dlrn.repositories import getdistrobranch
 from dlrn.repositories import getsourcebranch
 from dlrn.repositories import refreshrepo
+from dlrn.utils import fetch_remote_file
 from dlrn.utils import run_external_preprocess
 
 import csv
@@ -25,10 +26,8 @@ import re
 import sh
 import shutil
 
-from contextlib import closing
 from distroinfo import info
 from distroinfo import query
-from six.moves.urllib.request import urlopen
 
 
 logger = logging.getLogger("dlrn-downstream-driver")
@@ -139,8 +138,7 @@ class DownstreamInfoDriver(PkgInfoDriver):
 
         # return versions.csv as a dict with package name as a key
         vers = {}
-        with closing(urlopen(versions_url)) as r:
-            content = [x.decode('utf-8') for x in r.readlines()]
+        content = fetch_remote_file(versions_url)
         # first line is headers
         for row in csv.reader(content[1:]):
             vers[row[0]] = row[1:]
@@ -153,8 +151,7 @@ class DownstreamInfoDriver(PkgInfoDriver):
         versions_url = self.config_options.versions_url
         commit_url = re.sub('/versions.csv$', '/commit.yaml', versions_url)
         try:
-            with closing(urlopen(commit_url)) as r:
-                content = [x.decode('utf-8') for x in r.readlines()]
+            content = fetch_remote_file(commit_url)
             return content
         except Exception:
             # We do not want to fail on this
@@ -213,13 +210,15 @@ class DownstreamInfoDriver(PkgInfoDriver):
         distro_branch = self.config_options.downstream_distro_branch
         if not distro_branch:
             fail_req_config_missing('downstream_distro_branch')
-        source_branch = getsourcebranch(package)
+        source_branch = getsourcebranch(
+            package, default_branch=self.config_options.source)
         versions = self._getversions()
 
         ups_distro = package['master-distgit']
         ups_distro_dir = self._upstream_distgit_clone_dir(package['name'])
         ups_distro_dir_full = self.upstream_distgit_dir(package['name'])
-        ups_distro_branch = getdistrobranch(package)
+        ups_distro_branch = getdistrobranch(
+            package, default_branch=self.config_options.distro)
 
         # Downstream source git
         dsgit_attr = self.config_options.downstream_source_git_key
@@ -241,12 +240,12 @@ class DownstreamInfoDriver(PkgInfoDriver):
         if dev_mode is False:
             try:
                 distro_branch, extended_hash_dsdist, dt_extended = refreshrepo(
-                    distro, distro_dir, distro_branch, local=local,
-                    full_path=distro_dir_full)
+                    distro, distro_dir, self.config_options, distro_branch,
+                    local=local, full_path=distro_dir_full)
 
                 _, extended_hash_dssource, _ = refreshrepo(
-                    ds_source, dsgit_dir, dsgit_branch, local=local,
-                    full_path=dsgit_dir)
+                    ds_source, dsgit_dir, self.config_options, dsgit_branch,
+                    local=local, full_path=dsgit_dir)
 
                 extended_hash = '%s_%s' % (extended_hash_dsdist,
                                            extended_hash_dssource)
@@ -255,8 +254,9 @@ class DownstreamInfoDriver(PkgInfoDriver):
                 distro_hash = version[3]
                 # Also download upstream distgit
                 _, _, _ = refreshrepo(
-                    ups_distro, ups_distro_dir, distro_hash,
-                    local=local, full_path=ups_distro_dir_full)
+                    ups_distro, ups_distro_dir, self.config_options,
+                    distro_hash, local=local,
+                    full_path=ups_distro_dir_full)
 
             except Exception:
                 # The error was already logged by refreshrepo, and we want
@@ -270,11 +270,13 @@ class DownstreamInfoDriver(PkgInfoDriver):
             if not os.path.isdir(distro_dir):
                 # We should fail in this case, since we are running
                 # in dev mode, so no try/except
-                refreshrepo(distro, distro_dir, distro_branch, local=local,
+                refreshrepo(distro, distro_dir, self.config_options,
+                            distro_branch, local=local,
                             full_path=distro_dir_full)
             if not os.path.isdir(ups_distro_dir):
-                refreshrepo(ups_distro, ups_distro_dir, ups_distro_branch,
-                            local=local, full_path=ups_distro_dir_full)
+                refreshrepo(ups_distro, ups_distro_dir, self.config_options,
+                            ups_distro_branch, local=local,
+                            full_path=ups_distro_dir_full)
 
         # repo is usually a string, but if it contains more then one entry we
         # git clone into a project subdirectory
@@ -288,6 +290,7 @@ class DownstreamInfoDriver(PkgInfoDriver):
                 repo_dir = os.path.join(repo_dir, os.path.split(repo)[1])
             try:
                 source_branch, _, _ = refreshrepo(repo, repo_dir,
+                                                  self.config_options,
                                                   source_branch,
                                                   local=local)
             except Exception:
