@@ -23,6 +23,7 @@
 import logging
 import os
 import re
+import requests
 import sh
 
 from dlrn.db import Commit
@@ -33,8 +34,6 @@ from dlrn.utils import run_external_preprocess
 from pymod2pkg import module2package
 from pymod2pkg import module2upstream
 from rdopkg.utils import specfile
-from six.moves import urllib
-from six.moves.urllib.request import urlopen
 
 logger = logging.getLogger("dlrn-gitrepo-driver")
 
@@ -49,10 +48,12 @@ base_urls = ['https://opendev.org/openstack',
 def check_url(url):
     logger.info("Checking url %s" % url)
     try:
-        urlopen(url)
+        r = requests.get(url, timeout=10)
+        # If we have an error code, this will raise an exception
+        r.raise_for_status()
         # URL found
         return True
-    except (urllib.error.HTTPError, urllib.error.URLError):
+    except requests.exceptions.RequestException:
         # Trouble finding URL
         return False
 
@@ -171,6 +172,7 @@ class GitRepoDriver(PkgInfoDriver):
         local = kwargs.get('local')
         dev_mode = kwargs.get('dev_mode')
         datadir = self.config_options.datadir
+        source = self.config_options.source
 
         for url in base_urls:
             if check_url("%s/%s" % (url, module2upstream(package['name']))):
@@ -185,7 +187,8 @@ class GitRepoDriver(PkgInfoDriver):
         repo = package['upstream']
 
         distro_dir = self.distgit_dir(package['name'])
-        source_branch = getsourcebranch(package)
+        source_branch = getsourcebranch(package,
+                                        default_branch=source)
 
         if dev_mode is True:
             distro_hash = "dev"
@@ -210,6 +213,7 @@ class GitRepoDriver(PkgInfoDriver):
                 repo_dir = os.path.join(repo_dir, os.path.split(repo)[1])
             try:
                 source_branch, _, _ = refreshrepo(repo, repo_dir,
+                                                  self.config_options,
                                                   source_branch, local=local)
             except Exception:
                 # The error was already logged by refreshrepo, and the only
