@@ -47,6 +47,8 @@ def _mocked_get_environ(param, default=None):
         return '20150102034455'
     elif param == 'RELEASE_NUMBERING':
         return '0.date.hash'
+    elif param == 'RELEASE_MINOR':
+        return '1'
 
 
 class TestDriverRdoInfo(base.TestCase):
@@ -119,6 +121,7 @@ class TestDriverRdoInfo(base.TestCase):
                               _env={'LANG': 'C',
                                     'MOCK_CONFIG': '/tmp/test.cfg',
                                     'RELEASE_DATE': '20150102034455',
+                                    'RELEASE_MINOR': '1',
                                     'RELEASE_NUMBERING': '0.date.hash'})]
 
         self.assertEqual(sh_mock.call_args_list, expected)
@@ -143,6 +146,7 @@ class TestDriverRdoInfo(base.TestCase):
                               _env={'LANG': 'C',
                                     'MOCK_CONFIG': '/tmp/test.cfg',
                                     'RELEASE_DATE': '20150102034455',
+                                    'RELEASE_MINOR': '1',
                                     'RELEASE_NUMBERING': '0.date.hash'})]
 
         self.assertEqual(sh_mock.call_args_list, expected)
@@ -167,6 +171,7 @@ class TestDriverRdoInfo(base.TestCase):
                               _env={'LANG': 'C',
                                     'MOCK_CONFIG': '/tmp/test.cfg',
                                     'RELEASE_DATE': '20150102034455',
+                                    'RELEASE_MINOR': '1',
                                     'RELEASE_NUMBERING': '0.date.hash'})]
 
         self.assertEqual(sh_mock.call_args_list, expected)
