@@ -14,12 +14,11 @@ import hashlib
 import logging
 import os
 import re
+import requests
 import sh
 import sys
 import yaml
 
-import sqlalchemy
-
 from contextlib import contextmanager
 from dlrn.db import CIVote
 from dlrn.db import CIVote_Aggregate
@@ -145,10 +144,8 @@ def saveYAML(session, yamlfile):
     data = {}
 
     attrs = []
-    for a in dir(Commit):
-        if type(getattr(Commit, a)) == \
-                sqlalchemy.orm.attributes.InstrumentedAttribute:
-            attrs.append(a)
+    for a in Commit.__table__.columns.keys():
+        attrs.append(a)
     data['commits'] = []
     for commit in session.query(Commit).all():
         d = {}
@@ -157,10 +154,8 @@ def saveYAML(session, yamlfile):
         data['commits'].append(d)
 
     attrs = []
-    for a in dir(Project):
-        if type(getattr(Project, a)) == \
-                sqlalchemy.orm.attributes.InstrumentedAttribute:
-            attrs.append(a)
+    for a in Project.__table__.columns.keys():
+        attrs.append(a)
     data['projects'] = []
     for project in session.query(Project).all():
         d = {}
@@ -169,10 +164,8 @@ def saveYAML(session, yamlfile):
         data['projects'].append(d)
 
     attrs = []
-    for a in dir(CIVote):
-        if type(getattr(CIVote, a)) == \
-                sqlalchemy.orm.attributes.InstrumentedAttribute:
-            attrs.append(a)
+    for a in CIVote.__table__.columns.keys():
+        attrs.append(a)
     data['civotes'] = []
     for vote in session.query(CIVote).all():
         d = {}
@@ -181,10 +174,8 @@ def saveYAML(session, yamlfile):
         data['civotes'].append(d)
 
     attrs = []
-    for a in dir(CIVote_Aggregate):
-        if type(getattr(CIVote_Aggregate, a)) == \
-                sqlalchemy.orm.attributes.InstrumentedAttribute:
-            attrs.append(a)
+    for a in CIVote_Aggregate.__table__.columns.keys():
+        attrs.append(a)
     data['civotes_agg'] = []
     for vote in session.query(CIVote_Aggregate).all():
         d = {}
@@ -193,10 +184,8 @@ def saveYAML(session, yamlfile):
         data['civotes_agg'].append(d)
 
     attrs = []
-    for a in dir(User):
-        if type(getattr(User, a)) == \
-                sqlalchemy.orm.attributes.InstrumentedAttribute:
-            attrs.append(a)
+    for a in User.__table__.columns.keys():
+        attrs.append(a)
     data['users'] = []
     for user in session.query(User).all():
         d = {}
@@ -205,10 +194,8 @@ def saveYAML(session, yamlfile):
         data['users'].append(d)
 
     attrs = []
-    for a in dir(Promotion):
-        if type(getattr(Promotion, a)) == \
-                sqlalchemy.orm.attributes.InstrumentedAttribute:
-            attrs.append(a)
+    for a in Promotion.__table__.columns.keys():
+        attrs.append(a)
     data['promotions'] = []
     for promotion in session.query(Promotion).all():
         d = {}
@@ -224,10 +211,8 @@ def saveYAML(session, yamlfile):
 def saveYAML_commit(commit, yamlfile):
     data = {}
     attrs = []
-    for a in dir(Commit):
-        if type(getattr(Commit, a)) == \
-                sqlalchemy.orm.attributes.InstrumentedAttribute:
-            attrs.append(a)
+    for a in Commit.__table__.columns.keys():
+        attrs.append(a)
     data['commits'] = []
     # Add commit
     d = {}
@@ -439,6 +424,31 @@ def find_in_artifacts(artifacts, word):
             return artifact
 
 
+def fetch_remote_file(url):
+    '''Fetch a remote file and return a list of lines.
+
+    Extended to support file:/// URL encoding without the need to add
+    an extra dependency, like requests-file.
+    '''
+    result = []
+
+    if url.startswith('file://'):
+        with open(url.replace('file://', ''), 'r') as fp:
+            result.extend(fp.readlines())
+    else:
+        try:
+            r = requests.get(url, timeout=10)
+            # Raise an exception in case of a failure
+            r.raise_for_status()
+            for line in r.iter_lines():
+                result.extend([line.decode('utf-8') + '\n'])
+        except requests.exceptions.RequestException as e:
+            logger.warning('Failed to fetch remote file: %s' % e)
+            raise
+
+    return result
+
+
 if __name__ == '__main__':
     s = getSession('sqlite:///%s' % sys.argv[1])
     saveYAML(s, sys.argv[1] + ".yaml")
